Data Versions
=============

Every PUNCH file has a version (in addition to documenting internally the version of software used). This version is
either a number followed by a letter or simply a number. For example, version "0a" was the first version released
during commissioning. This document describes the state of each version.

Version 0b
----------
- Released June 1, 2025
- Small metadata improvements from 0a
- Includes Level 1 and Level Q products

Version 0a
-----------
- Released May 14, 2025
- Initial version released during commissioning
- Only Level 0 products
